@@ -1,10 +1,7 @@
 # General Imports
 import mysql
 from mysql.connector import errorcode
-from mysql.connector import FieldType
-from argparse import ArgumentParser
 from datetime import datetime
-from datetime import timedelta
 import json
 import logging
 from . import *
@@ -79,14 +76,16 @@ class Database:
             if cnx:
                 logger.debug("Assigning connection to attribute")
                 self.connection = cnx
+                self.get_version()
 
     def get_version(self):
         logger.name ="pyyomysql::Database::get_version"
         if self.connection is not None:
             logger.debug("Getting Database version")
             result = self.execute("SELECT @@version AS version")
-            self.version = result["rows"][0]["version"][:3]
-            self.full_version = result["rows"][0]["version"]
+            column_name = list(result["rows"][0].keys())[0]
+            self.version = result["rows"][0][column_name][:3]
+            self.full_version = result["rows"][0][column_name]
             return self.version
         else:
             logger.error("Connect first!")
@@ -214,11 +213,11 @@ class Database:
 
     def get_schemas(self):
         logger.name = "pyyomysql::Database::get_schemas"
-        response = self.execute("SELECT schema_name, default_character_set_name AS charset, default_collation_name as collation FROM information_schema.schemata")
+        response = self.execute("SELECT schema_name AS name, default_character_set_name AS charset, default_collation_name as collation FROM information_schema.schemata")
         results = {}
         for row in response["rows"]:
-            results[row["schema_name"]]= {
-                "name": row["schema_name"],
+            results[row["name"]]= {
+                "name": row["name"],
                 "charset": row["charset"],
                 "collation": row["collation"],
                 "tables": []
@@ -227,7 +226,7 @@ class Database:
 
     def get_schema(self, schema_name):
         logger.name = "pyyomysql::Database::get_schema"
-        result = self.execute(f"SELECT schema_name as 'name', default_character_set_name AS charset, default_collation_name as collation FROM information_schema.schemata WHERE schema_name = '{schema_name}'")['rows']
+        result = self.execute(f"SELECT schema_name AS 'name', default_character_set_name AS charset, default_collation_name as collation FROM information_schema.schemata WHERE schema_name = '{schema_name}'")['rows']
         if len(result) > 0:
             logger.debug(f'Schema {schema_name} found. Returning {result[0]}')
             return result[0]
@@ -240,7 +239,7 @@ class Database:
         logger.name = "pyyomysql::Database::get_users"
         from pyoomysql.User import User
         response = []
-        result = self.execute(f"SELECT user, host FROM mysql.user")
+        result = self.execute(f"SELECT user AS 'user', host FROM mysql.user")
         if len(result["rows"]) > 0:
             for row in result["rows"]:
                 if type(row["user"]) is bytearray:
@@ -253,7 +252,7 @@ class Database:
         from pyoomysql.User import User
         logger.name = "pyyomysql::Database::get_user_by_name"
         response = []
-        result = self.execute(f"SELECT user, host FROM mysql.user WHERE user = '{user}'")
+        result = self.execute(f"SELECT user AS 'user', host AS 'host' FROM mysql.user WHERE user = '{user}'")
         if len(result["rows"]) > 0:
             for row in result["rows"]:
                 if type(row["user"]) is bytearray:
@@ -265,7 +264,7 @@ class Database:
     def get_user_by_name_host(self, user, host):
         from pyoomysql.User import User
         logger.name = "pyyomysql::Database::get_user_by_name_host"
-        result = self.execute(f"SELECT user, host FROM mysql.user WHERE user = '{user}' AND host = '{host}'")
+        result = self.execute(f"SELECT user AS 'user', host AS 'host' FROM mysql.user WHERE user = '{user}' AND host = '{host}'")
         if result["rowcount"] == 1:
             if type(result["rows"][0]["user"]) is bytearray:
                 return User(database=self, user=result["rows"][0]["user"].decode(), host=result["rows"][0]["host"].decode())
@@ -284,34 +283,67 @@ class Database:
         else:
             return False
 
-    def get_replica_status(self):
-        result = self.execute(command="SHOW SLAVE STATUS")
+    def get_replica_status(self, channel=None):
+        if self.version.split(".")[0] == "5":
+            replication_word = "SLAVE"
+        else:
+            replication_word = "REPLICA"
+        sql_cmd = f"SHOW {replication_word} STATUS"
+        if channel is not None:
+            sql_cmd += f" FOR CHANNEL '{channel}'"
+        result = self.execute(command=sql_cmd)
         if len(result["rows"]) == 1:
             return result["rows"][0]
         else:
             return None
     
-    def configure_replica(self, primary_host, primary_port, replica_user, replica_pswd, binlog_file=None, binlog_pos=None):
-        sql = f"CHANGE MASTER TO MASTER_HOST='{primary_host}', MASTER_PORT={primary_port}, MASTER_USER='{replica_user}', MASTER_PASSWORD='{replica_pswd}' "
+    def configure_replica(self, primary_host, primary_port, replica_user, replica_pswd, binlog_file=None, binlog_pos=None,channel=None):
+        if self.version.split(".")[0] == "5":
+            replication_word = "SLAVE"
+            set_source_cmd = "CHANGE MASTER TO"
+        else:
+            replication_word = "REPLICA"
+            set_source_cmd = "CHANGE REPLICATION SOURCE TO"
+        sql = f"{set_source_cmd} MASTER_HOST='{primary_host}', MASTER_PORT={primary_port}, MASTER_USER='{replica_user}', MASTER_PASSWORD='{replica_pswd}' "
         if binlog_file is not None:
             sql+=f"MASTER_LOG_FILE='{binlog_file}' "
         if binlog_pos is not None:
             sql+=f"MASTER_LOG_POS={binlog_pos}"
+        if channel is not None:
+            sql+=f" FOR CHANNEL '{channel}'"
         return self.execute(sql)
 
-    def start_replica(self):
-        return self.execute(command="START SLAVE")
+    def start_replica(self, channel=None):
+        if self.version.split(".")[0] == "5":
+            replication_word = "SLAVE"
+        else:
+            replication_word = "REPLICA"
+        sql_cmd = f"START {replication_word}"
+        if channel is not None:
+            sql_cmd += f" FOR CHANNEL '{channel}'"
+        return self.execute(command=sql_cmd)
 
-    def stop_replica(self):
-        return self.execute(command="STOP SLAVE")
-    
-    def skip_replica_error(self, amount=1):
+    def stop_replica(self, channel=None):
+        if self.version.split(".")[0] == "5":
+            replication_word = "SLAVE"
+        else:
+            replication_word = "REPLICA"
+        sql_cmd = f"STOP {replication_word}"
+        if channel is not None:
+            sql_cmd += f" FOR CHANNEL '{channel}'"
+        return self.execute(command=sql_cmd)
+   
+    def skip_replica_error(self, channel=None, amount=1):
+        if self.version.split(".")[0] == "5":
+            replication_word = "SLAVE"
+        else:
+            replication_word = "REPLICA"
         logger.info("Stopping replication process...")
-        self.stop_replica()
+        self.stop_replica(channel)
         logger.info(f"Setting SQL_SLAVE_SKIP_COUNTER to {amount}")
-        self.execute(command=f"SET GLOBAL SQL_SLAVE_SKIP_COUNTER = {amount}")
+        self.execute(command=f"SET GLOBAL SQL_{replication_word}_SKIP_COUNTER = {amount}")
         logger.info("Starting replication process again...")
-        self.start_replica()
+        self.start_replica(channel)
         logger.info("All done.")
 
     # Check if there's an active connection to the database
