@@ -109,7 +109,7 @@ class Schema:
 
     def get_tables(self):
         if self.exists:
-            result = self.database.execute(f"SELECT table_schema AS schema_name, table_name, table_type, table_rows, avg_row_length, max_data_length FROM information_schema.tables WHERE table_schema = '{self.name}' ORDER by 1,2")
+            result = self.database.execute(f"SELECT table_schema AS schema_name, table_name AS table_name, table_type AS table_type, table_rows AS table_rows, avg_row_length AS avg_row_length, max_data_length AS max_data_length FROM information_schema.tables WHERE table_schema = '{self.name}' ORDER by 1,2")
             tables = {}
             for row in result['rows']:
                 tables[f"{row['table_name']}"] = {
@@ -129,7 +129,7 @@ class Schema:
 
     def get_table(self, table_name):
         if self.exists:
-            result = self.database.execute(f"SELECT table_schema AS schema_name, table_name, table_type, table_rows, avg_row_length, max_data_length FROM information_schema.tables WHERE table_schema = '{self.name}' AND table_name = '{table_name}' ORDER by 1,2")
+            result = self.database.execute(f"SELECT table_schema AS schema_name, table_name AS table_name, table_type, table_rows, avg_row_length, max_data_length FROM information_schema.tables WHERE table_schema = '{self.name}' AND table_name = '{table_name}' ORDER by 1,2")
             table = {}
             if len(result) > 0:
                 table[f"{result['table_name']}"] = result[0]
@@ -137,6 +137,9 @@ class Schema:
             table_obj = Table(schema=self, name=table_name)
             table['columns'] = table_obj.get_columns()
             return table
+    
+    def migrate(self,target_schema):
+        pass
 
     def compare(self, schema, gen_fix_script=False):
         if self.exists:
