@@ -34,7 +34,7 @@ class Table:
         self.schema = schema
         self.database = schema.database
         self.fqn = f"{self.schema.name}.{self.name}"
-        result = self.database.execute(command = f"SELECT table_schema, table_name, table_type, table_collation FROM information_schema.TABLES WHERE table_schema = '{self.schema.name}' AND table_name = '{self.name}'")
+        result = self.database.execute(command = f"SELECT table_schema AS table_schema, table_name AS table_name, table_type AS table_type, table_collation AS table_collation FROM information_schema.TABLES WHERE table_schema = '{self.schema.name}' AND table_name = '{self.name}'")
         self.ddl = ""
         self.columns = []
         self.keys = {}
@@ -48,7 +48,10 @@ class Table:
     def __str__(self):
         column_list = []
         for column in self.columns:
-            column_list.append(f"{column.name} {column.type}({column.length})")
+            if column.length == 0:
+                column_list.append(f"{column.name} {column.type}")
+            else:
+                column_list.append(f"{column.name} {column.type}({column.length})")
         return json.dumps({
             "database": f"{self.database.hostname}:{self.database.port}",
             "schema": f"{self.schema.name}",
@@ -70,19 +73,20 @@ class Table:
     # Methods
     def get_columns(self):
         # logger.log(DEBUG, f"Table is: {table_name}")
-        result = self.database.execute(f"SELECT column_name, ordinal_position, data_type, column_default, is_nullable, column_type, character_set_name, collation_name FROM information_schema.columns WHERE table_schema = '{self.schema.name}' AND table_name = '{self.name}' ORDER BY ordinal_position")
+        result = self.database.execute(f"SELECT column_name AS name, ordinal_position AS position, data_type AS data_type, column_default AS column_default, is_nullable AS is_nullable, column_type AS column_type, character_set_name AS charset, collation_name AS collation FROM information_schema.columns WHERE table_schema = '{self.schema.name}' AND table_name = '{self.name}' ORDER BY ordinal_position")
         column_list = []
         for column in result['rows']:
             # logger.log(DEBUG, column)
             column_list.append(
                 Column(
                     table               = self,
-                    name                = column['column_name'],
-                    ordinal_position    = column['ordinal_position'],
+                    name                = column['name'],
+                    ordinal_position    = column['position'],
                     type                = column['data_type'], 
                     default             = column['column_default'],
                     nullable            = column['is_nullable'], 
-                    charset             = column['character_set_name'],
+                    charset             = column['charset'],
+                    collation           = column['collation'],
                     length              = 0
                 )
             )
@@ -141,9 +145,9 @@ class Table:
                                 if word.find("(") != -1:
                                     column_type=word.split("(")[0]
                                     column_length=word.split("(")[1].split(")")[0]
-                                    index+=1
                                 else:
                                     column_type = word
+                                index+=1
                             elif index > 1:
                                 if word == "unsigned":
                                     column_unsigned: True
@@ -172,7 +176,10 @@ class Table:
                         )
                         if len(self.columns) > 1:
                             self.ddl+=", "
-                        self.ddl += f"{column_name} {column_type}({column_length})"
+                        if column_length == 0:
+                            self.ddl += f"{column_name} {column_type}"
+                        else:
+                            self.ddl += f"{column_name} {column_type}({column_length})"
                         if not column_nullable:
                             self.ddl+=f" NOT NULL"
                         if column_default is not None:
